@@ -107,7 +107,12 @@ class Constants:
     NAME = "name"
     TYPE = "type"
     GUID = "guid"
+    DESCRIPTION = "description"
+    LABEL = "label"
+    HANDLER = "handler"
     CREDMGR_HOST = "credmgr-host"
+    PUBLISH_INTERVAL = "publish-interval"
+    DELEGATION = "delegation"
 
     PROPERTY_CLASS_NAME = "ObjectClassName"
     PROPERTY_MODULE_NAME = "ModuleName"
@@ -160,28 +165,29 @@ class Constants:
 
     CONFIG_SECTION_NEO4J = "neo4j"
 
+    PROPERTY_CONF_MODULE_NAME = 'module'
+    PROPERTY_CONF_CLASS_NAME = 'class'
+    PROPERTY_CONF_PROPERTIES_NAME = 'properties'
+
     PROTOCOL_LOCAL = "local"
     PROTOCOL_KAFKA = "kafka"
 
     HOME_DIRECTORY = '/usr/src/app/'
     SUPERBLOCK_LOCATION = HOME_DIRECTORY + "state_recovery.lock"
-    CONTROLLER_LOCK_LOCATION = HOME_DIRECTORY + "controller_recovery.lock"
     CONFIGURATION_FILE = "/etc/fabric/actor/config/config.yaml"
     STATE_FILE_LOCATION = '/tmp/fabric_actor.tmp'
 
     ELASTIC_TIME = "request.elasticTime"
     ELASTIC_SIZE = "request.elasticSize"
 
-    POOL_NAME = 'pool.name'
-    POOL_PREFIX = "pool."
-    POOLS_COUNT = "pools.count"
-    QUERY_ACTION_DISCOVER_POOLS = "discover.pools"
+    QUERY_ACTION_DISCOVER_BQM = "discover.bqm"
     QUERY_ACTION = "query.action"
     QUERY_RESPONSE = "query.response"
     QUERY_RESPONSE_STATUS = "query.response.status"
     QUERY_RESPONSE_MESSAGE = "query.response.message"
     QUERY_DETAIL_LEVEL = "query.detail.level"
     BROKER_QUERY_MODEL = "bqm"
+    BROKER_QUERY_MODEL_FORMAT = "bqm.format"
     POOL_TYPE = "neo4j"
 
     UNIT_MODIFY_PROP_MESSAGE_SUFFIX = ".message"
