@@ -314,6 +314,27 @@ class Globals:
         producer = AvroProducerApi(conf=conf, key_schema=key_schema, record_schema=val_schema, logger=self.get_logger())
         return producer
 
+    def get_simple_kafka_producer(self):
+        """
+        Create and return a kafka producer
+        @return producer
+        """
+        conf = self.get_kafka_config_producer()
+        if conf is not None:
+            conf.pop(Constants.SCHEMA_REGISTRY_URL)
+
+        bqm_config = self.config.get_global_config().get_bqm_config()
+        if bqm_config is not None:
+            prod_user_name = bqm_config.get(Constants.PROPERTY_CONF_KAFKA_SASL_PRODUCER_USERNAME, None)
+            prod_password = bqm_config.get(Constants.PROPERTY_CONF_KAFKA_SASL_PRODUCER_PASSWORD, None)
+            if prod_user_name is not None and prod_password is not None:
+                conf[Constants.SASL_USERNAME] = prod_user_name
+                conf[Constants.SASL_PASSWORD] = prod_password
+
+        from confluent_kafka import Producer
+        producer = Producer(conf)
+        return producer
+
     def get_kafka_admin_client(self):
         """
         Create and return a kafka admin client
@@ -390,7 +411,7 @@ class Globals:
         Start the timer thread
         """
         if self.timer_thread is not None:
-            raise RuntimeError("This actor has already been started")
+            raise RuntimeError("This timer thread has already been started")
 
         self.timer_thread = threading.Thread(target=self.timer_loop)
         self.timer_thread.setName('GlobalTimer')
