@@ -355,14 +355,9 @@ class ActorMixin(ABCActorMixin):
         from fabric_cf.actor.core.container.globals import GlobalsSingleton
 
         if not self.initialized:
-            if self.identity is None:
-                raise ActorException("The actor is not properly created: no identity")
-
-            if self.plugin is None:
-                raise ActorException("The actor is not properly created: no plugin")
-
-            if self.policy is None:
-                raise ActorException("The actor is not properly created: no policy")
+            if self.identity is None or self.plugin is None or self.policy is None:
+                raise ActorException(f"The actor is not properly created: identity: {self.identity} "
+                                     f"plugin: {self.plugin} policy: {self.policy}")
 
             if self.name is None:
                 self.name = self.identity.get_name()
@@ -633,6 +628,9 @@ class ActorMixin(ABCActorMixin):
     def register_slice(self, *, slice_object: ABCSlice):
         self.wrapper.register_slice(slice_object=slice_object)
 
+    def register_delegation(self, *, delegation: ABCDelegation):
+        self.wrapper.register_delegation(delegation=delegation)
+
     def remove_reservation(self, *, reservation: ABCReservationMixin = None, rid: ID = None):
         if reservation is not None:
             self.wrapper.remove_reservation(rid=reservation.get_reservation_id())
@@ -761,10 +759,14 @@ class ActorMixin(ABCActorMixin):
         Actor run function for actor thread
         """
         try:
+            self.logger.info("Actor Main Thread started")
             self.actor_count -= 1
             self.actor_main()
         except Exception as e:
-            self.logger.error("Unexpected error {}".format(e))
+            self.logger.error(f"Unexpected error {e}")
+            self.logger.error(traceback.format_exc())
+        finally:
+            self.logger.info("Actor Main Thread exited")
 
     def start(self):
         """
@@ -803,6 +805,7 @@ class ActorMixin(ABCActorMixin):
                     temp.join()
                 except Exception as e:
                     self.logger.error("Could not join actor thread {}".format(e))
+                    self.logger.error(traceback.format_exc())
                 finally:
                     self.thread_lock.release()
         finally:
@@ -898,12 +901,20 @@ class ActorMixin(ABCActorMixin):
                     return
 
                 if not self.event_queue.empty():
-                    for event in IterableQueue(source_queue=self.event_queue):
-                        events.append(event)
+                    try:
+                        for event in IterableQueue(source_queue=self.event_queue):
+                            events.append(event)
+                    except Exception as e:
+                        self.logger.error(f"Error while adding event to event queue! e: {e}")
+                        self.logger.error(traceback.format_exc())
 
                 if not self.timer_queue.empty():
-                    for timer in IterableQueue(source_queue=self.timer_queue):
-                        timers.append(timer)
+                    try:
+                        for timer in IterableQueue(source_queue=self.timer_queue):
+                            timers.append(timer)
+                    except Exception as e:
+                        self.logger.error(f"Error while adding event to event queue! e: {e}")
+                        self.logger.error(traceback.format_exc())
 
                 self.actor_main_lock.notify_all()
 
@@ -915,8 +926,8 @@ class ActorMixin(ABCActorMixin):
                     try:
                         e.process()
                     except Exception as e:
-                        self.logger.error(traceback.format_exc())
                         self.logger.error("Error while processing event {} {}".format(type(e), e))
+                        self.logger.error(traceback.format_exc())
 
             if len(timers) > 0:
                 for t in timers:
@@ -924,6 +935,7 @@ class ActorMixin(ABCActorMixin):
                         t.execute()
                     except Exception as e:
                         self.logger.error("Error while processing a timer {}".format(e))
+                        self.logger.error(traceback.format_exc())
 
     def setup_message_service(self):
         """
