@@ -283,8 +283,6 @@ class AuthorityReservation(ReservationServer, ABCKernelAuthorityReservationMixin
                     self.previous_term = self.term
                     self.ticket = self.requested_resources
                     self.term = self.approved_term
-                    if self.requested_resources.get_sliver() is not None:
-                        self.approved_resources.set_sliver(sliver=self.requested_resources.get_sliver())
 
                     self.resources.update(reservation=self, resource_set=self.approved_resources)
                     self.transition(prefix="extend lease", state=ReservationStates.Active,
@@ -561,10 +559,9 @@ class AuthorityReservation(ReservationServer, ABCKernelAuthorityReservationMixin
     def get_notices(self) -> str:
         s = super().get_notices()
         if self.resources is not None and self.resources.get_resources() is not None:
-            cs = self.resources.get_resources()
-            notices = cs.get_notices()
-            if notices is not None:
-                s += f" {notices}"
+            resource_notices = self.resources.get_resources().get_notices()
+            if resource_notices is not None:
+                s += f" {resource_notices}"
 
         return s
 
