@@ -30,12 +30,12 @@ import traceback
 from datetime import datetime
 from typing import TYPE_CHECKING
 
-from fabric_cf.actor.core.common.exceptions import BrokerException
+from fabric_cf.actor.core.common.exceptions import BrokerException, ExceptionErrorCode
 from fabric_cf.actor.core.util.id import ID
-from fabric_cf.actor.core.apis.i_authority_policy import IAuthorityPolicy
-from fabric_cf.actor.core.apis.i_broker_policy import IBrokerPolicy
-from fabric_cf.actor.core.apis.i_reservation import ReservationCategory
-from fabric_cf.actor.core.apis.i_kernel_broker_reservation import IKernelBrokerReservation
+from fabric_cf.actor.core.apis.abc_authority_policy import ABCAuthorityPolicy
+from fabric_cf.actor.core.apis.abc_broker_policy_mixin import ABCBrokerPolicyMixin
+from fabric_cf.actor.core.apis.abc_reservation_mixin import ReservationCategory
+from fabric_cf.actor.core.apis.abc_kernel_broker_reservation_mixin import ABCKernelBrokerReservationMixin
 from fabric_cf.actor.core.kernel.rpc_manager_singleton import RPCManagerSingleton
 from fabric_cf.actor.core.kernel.rpc_request_type import RPCRequestType
 from fabric_cf.actor.core.kernel.request_types import RequestTypes
@@ -43,19 +43,19 @@ from fabric_cf.actor.core.kernel.reservation_server import ReservationServer
 from fabric_cf.actor.core.kernel.reservation_states import ReservationStates, ReservationPendingStates
 
 if TYPE_CHECKING:
-    from fabric_cf.actor.core.apis.i_actor import IActor
-    from fabric_cf.actor.core.apis.i_authority_proxy import IAuthorityProxy
-    from fabric_cf.actor.core.apis.i_callback_proxy import ICallbackProxy
-    from fabric_cf.actor.core.apis.i_delegation import IDelegation
-    from fabric_cf.actor.core.apis.i_policy import IPolicy
-    from fabric_cf.actor.core.apis.i_slice import ISlice
+    from fabric_cf.actor.core.apis.abc_actor_mixin import ABCActorMixin
+    from fabric_cf.actor.core.apis.abc_authority_proxy import ABCAuthorityProxy
+    from fabric_cf.actor.core.apis.abc_callback_proxy import ABCCallbackProxy
+    from fabric_cf.actor.core.apis.abc_delegation import ABCDelegation
+    from fabric_cf.actor.core.apis.abc_policy import ABCPolicy
+    from fabric_cf.actor.core.apis.abc_slice import ABCSlice
     from fabric_cf.actor.core.kernel.failed_rpc import FailedRPC
-    from fabric_cf.actor.core.apis.i_kernel_slice import IKernelSlice
+    from fabric_cf.actor.core.apis.abc_kernel_slice import ABCKernelSlice
     from fabric_cf.actor.core.kernel.resource_set import ResourceSet
     from fabric_cf.actor.core.time.term import Term
 
 
-class BrokerReservation(ReservationServer, IKernelBrokerReservation):
+class BrokerReservation(ReservationServer, ABCKernelBrokerReservationMixin):
     """
     A note on exported "will call" reservations. An export() operation may be
     locally initiated on an agent. It binds and forms a ticket in the same way as
@@ -69,7 +69,7 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
     """
     updated_absorbed = "update absorbed"
 
-    def __init__(self, *, rid: ID, resources: ResourceSet, term: Term, slice_obj: IKernelSlice):
+    def __init__(self, *, rid: ID, resources: ResourceSet, term: Term, slice_obj: ABCKernelSlice):
         super().__init__(rid=rid, resources=resources, term=term, slice_object=slice_obj)
         # Delegation backing the ticket granted to this reservation. For now only
         # one source delegation can be used to issue a ticket to satisfy a client
@@ -129,7 +129,7 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
         self.notified_failed = False
         self.closed_in_priming = False
 
-    def restore(self, *, actor: IActor, slice_obj: ISlice):
+    def restore(self, *, actor: ABCActorMixin, slice_obj: ABCSlice):
         """
         Must be invoked after creating reservation from unpickling
         """
@@ -154,12 +154,12 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
         """
         Recover the reservation post stateful restart
         """
-        if isinstance(self.policy, IAuthorityPolicy):
+        if isinstance(self.policy, ABCAuthorityPolicy):
             self.logger.debug("No recovery necessary for reservation #{}".format(self.get_reservation_id()))
             return
 
-        if not isinstance(self.policy, IBrokerPolicy):
-            raise BrokerException("Do not know how to recover: policy={}".format(self.policy))
+        if not isinstance(self.policy, ABCBrokerPolicyMixin):
+            raise BrokerException(msg=f"Do not know how to recover: policy={self.policy}")
 
         if self.state == ReservationStates.Nascent:
             if self.pending_state == ReservationPendingStates.None_:
@@ -176,7 +176,8 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
                                                                                    self.print_state()))
 
             else:
-                raise BrokerException("Unexpected pending state")
+                raise BrokerException(error_code=ExceptionErrorCode.UNEXPECTED_STATE,
+                                      msg=f"pending_state={self.pending_state}")
 
         elif self.state == ReservationStates.Ticketed:
             if self.pending_state == ReservationPendingStates.None_ or \
@@ -193,27 +194,30 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
                     "Added reservation #{} to the extending list. State={}".format(self.get_reservation_id(),
                                                                                    self.print_state()))
             else:
-                raise BrokerException("Unexpected pending state")
+                raise BrokerException(error_code=ExceptionErrorCode.UNEXPECTED_STATE,
+                                      msg=f"pending_state={self.pending_state}")
 
         elif self.state == ReservationStates.Failed:
             self.logger.warning("Reservation #{} has failed".format(self.get_reservation_id()))
         else:
-            raise BrokerException("Unexpected reservation state")
+            raise BrokerException(error_code=ExceptionErrorCode.UNEXPECTED_STATE,
+                                  msg=f"state={self.state}")
 
     def handle_failed_rpc(self, *, failed: FailedRPC):
         # make sure that the failed RPC came from the callback identity
         remote_auth = failed.get_remote_auth()
         if failed.get_request_type() == RPCRequestType.UpdateTicket:
             if self.callback is None or self.callback.get_identity() != remote_auth:
-                raise BrokerException("Unauthorized Failed reservation RPC: expected={}, but was: {}".format(
-                    self.callback.get_identity(), remote_auth))
+                raise BrokerException(msg=f"Unauthorized Failed reservation RPC: "
+                                          f"expected={self.callback.get_identity()}, but was: {remote_auth}")
         else:
-            raise BrokerException("Unexpected FailedRPC for BrokerReservation. RequestType={}".format(
-                failed.get_request_type()))
+            raise BrokerException(error_code=ExceptionErrorCode.NOT_SUPPORTED,
+                                  msg=f"Unexpected FailedRPC for BrokerReservation. "
+                                      f"RequestType={failed.get_request_type()}")
 
         super().handle_failed_rpc(failed=failed)
 
-    def prepare(self, *, callback: ICallbackProxy, logger):
+    def prepare(self, *, callback: ABCCallbackProxy, logger):
         self.set_logger(logger=logger)
         self.callback = callback
 
@@ -226,7 +230,7 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
 
         self.set_dirty()
 
-    def reserve(self, *, policy: IPolicy):
+    def reserve(self, *, policy: ABCPolicy):
         # These handlers may need to be slightly more sophisticated, since a
         # client may bid multiple times on a ticket as part of an auction
         # protocol: so we may receive a reserve or extend when there is already
@@ -254,7 +258,7 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
                                 pending=ReservationPendingStates.None_)
                 self.generate_update()
 
-    def extend_ticket(self, *, actor: IActor):
+    def extend_ticket(self, *, actor: ABCActorMixin):
         self.incoming_request()
 
         # State must be ticketed. The reservation may be active, but the agent wouldn't know that
@@ -266,7 +270,7 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
             self.error(err="extending reservation with another pending request")
 
         if not self.requested_term.extends_term(old_term=self.term):
-            self.error(err="new term does not extend current term")
+            self.error(err=f"new term {self.requested_term} does not extend current term {self.term}")
 
         self.approved = False
         self.bid_pending = True
@@ -375,7 +379,8 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
             self.logger.debug("no op")
 
         else:
-            raise BrokerException("unsupported operation {}".format(RequestTypes(operation).name))
+            raise BrokerException(error_code=ExceptionErrorCode.NOT_SUPPORTED,
+                                  msg=f"operation {RequestTypes(operation).name}")
 
     def generate_update(self):
         self.logger.debug("Generating update")
@@ -463,7 +468,7 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
 
                     # If the policy has processed this reservation, set granted to
                     # true so that we can send the ticket back to the client. If
-                    # the policy has not yet processed this reservation (binPending
+                    # the policy has not yet processed this reservation (bid_pending
                     # is true) then call the policy. The plugin may choose to
                     # process the request immediately (true) or to defer it
                     # (false). In case of a deferred request, we will eventually
@@ -499,10 +504,10 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
 
         return success
 
-    def get_authority(self) -> IAuthorityProxy:
+    def get_authority(self) -> ABCAuthorityProxy:
         return self.authority
 
-    def get_source(self) -> IDelegation:
+    def get_source(self) -> ABCDelegation:
         return self.source
 
     def get_units(self, *, when: datetime = None) -> int:
@@ -521,12 +526,29 @@ class BrokerReservation(ReservationServer, IKernelBrokerReservation):
     def set_exporting(self):
         self.exporting = True
 
-    def set_source(self, *, source: IDelegation):
+    def set_source(self, *, source: ABCDelegation):
         """
         Set source
         @param source source
         """
         self.source = source
 
-    def set_authority(self, *, authority: IAuthorityProxy):
+    def set_authority(self, *, authority: ABCAuthorityProxy):
         self.authority = authority
+
+
+class BrokerReservationFactory:
+    @staticmethod
+    def create(*, rid: ID, resources: ResourceSet, term: Term, slice_obj: ABCSlice, actor: ABCActorMixin = None):
+        """
+        Create Broker Reservation
+        :param rid:
+        :param resources:
+        :param term:
+        :param slice_obj:
+        :param actor:
+        :return:
+        """
+        reservation = BrokerReservation(rid=rid, resources=resources, term=term, slice_obj=slice_obj)
+        reservation.restore(actor=actor, slice_obj=slice_obj)
+        return reservation
