@@ -42,7 +42,7 @@ from fabric_cf.actor.core.apis.abc_client_actor_management_object import ABCClie
 if TYPE_CHECKING:
     from fabric_mb.message_bus.messages.result_proxy_avro import ResultProxyAvro
     from fabric_mb.message_bus.messages.proxy_avro import ProxyAvro
-    from fabric_mb.message_bus.messages.result_pool_info_avro import ResultPoolInfoAvro
+    from fabric_mb.message_bus.messages.result_broker_query_model_avro import ResultBrokerQueryModelAvro
     from fabric_mb.message_bus.messages.result_string_avro import ResultStringAvro
     from fabric_mb.message_bus.messages.ticket_reservation_avro import TicketReservationAvro
     from fabric_mb.message_bus.messages.result_strings_avro import ResultStringsAvro
@@ -52,7 +52,6 @@ if TYPE_CHECKING:
     from fabric_cf.actor.core.apis.abc_actor_mixin import ABCActorMixin
     from fabric_cf.actor.security.auth_token import AuthToken
     from fabric_cf.actor.core.util.id import ID
-    from fabric_cf.actor.core.util.resource_type import ResourceType
     from fabric_cf.actor.core.apis.abc_substrate_database import ABCSubstrateDatabase
 
 
@@ -94,8 +93,9 @@ class ControllerManagementObject(ActorManagementObject, ABCClientActorManagement
     def add_broker(self, *, broker: ProxyAvro, caller: AuthToken) -> ResultAvro:
         return self.client_helper.add_broker(broker=broker, caller=caller)
 
-    def get_pool_info(self, *, broker: ID, caller: AuthToken, id_token: str, level: int) -> ResultPoolInfoAvro:
-        return self.client_helper.get_pool_info(broker=broker, caller=caller, id_token=id_token, level=level)
+    def get_broker_query_model(self, *, broker: ID, caller: AuthToken, id_token: str,
+                               level: int) -> ResultBrokerQueryModelAvro:
+        return self.client_helper.get_broker_query_model(broker=broker, caller=caller, id_token=id_token, level=level)
 
     def add_reservation(self, *, reservation: TicketReservationAvro, caller: AuthToken) -> ResultStringAvro:
         return self.client_helper.add_reservation(reservation=reservation, caller=caller)
@@ -110,12 +110,9 @@ class ControllerManagementObject(ActorManagementObject, ABCClientActorManagement
         return self.client_helper.demand_reservation(reservation=reservation, caller=caller)
 
     def extend_reservation(self, *, reservation: id, new_end_time: datetime, new_units: int,
-                           new_resource_type: ResourceType, request_properties: dict,
-                           config_properties: dict, caller: AuthToken) -> ResultAvro:
+                           caller: AuthToken) -> ResultAvro:
         return self.client_helper.extend_reservation(reservation=reservation, new_end_time=new_end_time, 
-                                                     new_units=new_units, new_resource_type=new_resource_type,
-                                                     request_properties=request_properties, 
-                                                     config_properties=config_properties, caller=caller)
+                                                     new_units=new_units, caller=caller)
 
     def modify_reservation(self, *, rid: ID, modify_properties: dict, caller: AuthToken) -> ResultAvro:
         return self.client_helper.modify_reservation(rid=rid, modify_properties=modify_properties, caller=caller)
