@@ -74,7 +74,8 @@ class KafkaActor(KafkaProxy, ABCMgmtActor):
             request.callback_topic = self.callback_topic
             request.message_id = str(ID())
             request.id_token = id_token
-            request.slice_id = slice_id
+            if slice_id is not None:
+                request.slice_id = str(slice_id)
             request.slice_name = slice_name
 
             ret_val = self.producer.produce_sync(topic=self.kafka_topic, record=request)
@@ -253,7 +254,7 @@ class KafkaActor(KafkaProxy, ABCMgmtActor):
         return status.code == 0
 
     def get_reservations(self, *, id_token: str = None, state: int = None,
-                         slice_id: ID = None, rid: ID = None) -> List[ReservationMng]:
+                         slice_id: ID = None, rid: ID = None, oidc_claim_sub: str = None) -> List[ReservationMng]:
         self.clear_last()
         response = ResultReservationAvro()
         response.status = ResultAvro()
@@ -362,7 +363,7 @@ class KafkaActor(KafkaProxy, ABCMgmtActor):
 
         return response.delegations
 
-    def remove_reservation(self, *, rid: ID) -> bool:
+    def remove_reservation(self, *, rid: ID, id_token: str = None) -> bool:
         status = ResultAvro()
         self.clear_last()
         if rid is None:
@@ -379,6 +380,7 @@ class KafkaActor(KafkaProxy, ABCMgmtActor):
             request.callback_topic = self.callback_topic
             request.message_id = str(ID())
             request.reservation_id = str(rid)
+            request.id_token = id_token
 
             ret_val = self.producer.produce_sync(topic=self.kafka_topic, record=request)
 
@@ -414,7 +416,7 @@ class KafkaActor(KafkaProxy, ABCMgmtActor):
 
         return status.code == 0
 
-    def close_reservation(self, *, rid: ID) -> bool:
+    def close_reservation(self, *, rid: ID, id_token: str = None) -> bool:
         status = ResultAvro()
         self.clear_last()
         if rid is None:
@@ -431,6 +433,7 @@ class KafkaActor(KafkaProxy, ABCMgmtActor):
             request.callback_topic = self.callback_topic
             request.message_id = str(ID())
             request.reservation_id = str(rid)
+            request.id_token = id_token
 
             ret_val = self.producer.produce_sync(topic=self.kafka_topic, record=request)
 
@@ -466,7 +469,7 @@ class KafkaActor(KafkaProxy, ABCMgmtActor):
 
         return status.code == 0
 
-    def close_reservations(self, *, slice_id: ID) -> bool:
+    def close_reservations(self, *, slice_id: ID, id_token: str = None) -> bool:
         status = ResultAvro()
         self.clear_last()
         if slice_id is None:
@@ -483,6 +486,7 @@ class KafkaActor(KafkaProxy, ABCMgmtActor):
             request.callback_topic = self.callback_topic
             request.message_id = str(ID())
             request.slice_id = str(slice_id)
+            request.id_token = id_token
 
             ret_val = self.producer.produce_sync(topic=self.kafka_topic, record=request)
 
