@@ -37,8 +37,8 @@ from fabric_mb.message_bus.messages.delegation_avro import DelegationAvro
 from fabric_mb.message_bus.messages.demand_reservation_avro import DemandReservationAvro
 from fabric_mb.message_bus.messages.extend_reservation_avro import ExtendReservationAvro
 from fabric_mb.message_bus.messages.get_actors_request_avro import GetActorsRequestAvro
-from fabric_mb.message_bus.messages.get_pool_info_request_avro import GetPoolInfoRequestAvro
-from fabric_mb.message_bus.messages.pool_info_avro import PoolInfoAvro
+from fabric_mb.message_bus.messages.get_broker_query_model_request_avro import GetBrokerQueryModelRequestAvro
+from fabric_mb.message_bus.messages.broker_query_model_avro import BrokerQueryModelAvro
 from fabric_mb.message_bus.messages.proxy_avro import ProxyAvro
 from fabric_mb.message_bus.messages.reclaim_resources_avro import ReclaimResourcesAvro
 from fabric_mb.message_bus.messages.reservation_mng import ReservationMng
@@ -296,13 +296,13 @@ class KafkaBroker(KafkaServerActor, ABCMgmtBrokerMixin):
 
         return rret_val
 
-    def get_pool_info(self, *, broker: ID, id_token: str, level: int) -> List[PoolInfoAvro]:
+    def get_broker_query_model(self, *, broker: ID, id_token: str, level: int) -> BrokerQueryModelAvro:
         self.clear_last()
         status = ResultAvro()
         rret_val = None
 
         try:
-            request = GetPoolInfoRequestAvro()
+            request = GetBrokerQueryModelRequestAvro()
             request.id_token = id_token
             request.guid = str(self.management_id)
             request.auth = self.auth
@@ -330,7 +330,7 @@ class KafkaBroker(KafkaServerActor, ABCMgmtBrokerMixin):
                     self.logger.debug(Constants.MANAGEMENT_INTER_ACTOR_INBOUND_MESSAGE.format(message_wrapper.response))
                     status = message_wrapper.response.status
                     if status.code == 0:
-                        rret_val = message_wrapper.response.pools
+                        rret_val = message_wrapper.response.model
             else:
                 self.logger.debug(Constants.MANAGEMENT_INTER_ACTOR_MESSAGE_FAILED.format(
                     request.name, self.kafka_topic))
@@ -347,26 +347,7 @@ class KafkaBroker(KafkaServerActor, ABCMgmtBrokerMixin):
 
         return rret_val
 
-    def extend_reservation_end_time(self, *, reservation: ID, new_end_time: datetime) -> bool:
-        return self.extend_reservation(reservation=reservation, new_end_time=new_end_time,
-                                       new_units=Constants.EXTEND_SAME_UNITS)
-
-    def extend_reservation_end_time_request(self, *, reservation: ID, new_end_time: datetime,
-                                            request_properties: dict) -> bool:
-        return self.extend_reservation(reservation=reservation, new_end_time=new_end_time,
-                                       new_units=Constants.EXTEND_SAME_UNITS,
-                                       request_properties=request_properties)
-
-    def extend_reservation_end_time_request_config(self, *, reservation: ID, new_end_time: datetime,
-                                                   request_properties: dict, config_properties: dict) -> bool:
-        return self.extend_reservation(reservation=reservation, new_end_time=new_end_time,
-                                       new_units=Constants.EXTEND_SAME_UNITS,
-                                       request_properties=request_properties,
-                                       config_properties=config_properties)
-
-    def extend_reservation(self, *, reservation: ID, new_end_time: datetime, new_units: int,
-                           new_resource_type: ResourceType = None, request_properties: dict = None,
-                           config_properties: dict = None) -> bool:
+    def extend_reservation(self, *, reservation: ID, new_end_time: datetime) -> bool:
         self.clear_last()
         status = ResultAvro()
 
@@ -377,11 +358,7 @@ class KafkaBroker(KafkaServerActor, ABCMgmtBrokerMixin):
             request.message_id = str(ID())
             request.callback_topic = self.callback_topic
             request.rid = str(reservation)
-            if new_units is not None:
-                request.new_units = new_units
-            request.new_resource_type = new_resource_type
-            request.request_properties = request_properties
-            request.config_properties = config_properties
+            request.new_units = Constants.EXTEND_SAME_UNITS
 
             ret_val = self.producer.produce_sync(topic=self.kafka_topic, record=request)
 
