@@ -32,14 +32,13 @@ from typing import List
 from fabric_mb.message_bus.messages.reservation_mng import ReservationMng
 from fabric_mb.message_bus.messages.ticket_reservation_avro import TicketReservationAvro
 from fabric_mb.message_bus.messages.delegation_avro import DelegationAvro
-from fabric_mb.message_bus.messages.pool_info_avro import PoolInfoAvro
+from fabric_mb.message_bus.messages.broker_query_model_avro import BrokerQueryModelAvro
 from fabric_mb.message_bus.messages.get_actors_request_avro import GetActorsRequestAvro
 from fabric_mb.message_bus.messages.proxy_avro import ProxyAvro
 from fabric_mb.message_bus.messages.get_reservation_units_request_avro import GetReservationUnitsRequestAvro
 from fabric_mb.message_bus.messages.result_avro import ResultAvro
 from fabric_mb.message_bus.messages.unit_avro import UnitAvro
 
-from fabric_cf.actor.core.util.resource_type import ResourceType
 from fabric_cf.actor.core.apis.abc_actor_mixin import ActorType
 from fabric_cf.actor.core.common.exceptions import ManageException
 from fabric_cf.actor.core.apis.abc_mgmt_controller_mixin import ABCMgmtControllerMixin
@@ -110,7 +109,7 @@ class KafkaController(KafkaActor, ABCMgmtControllerMixin):
 
         return rret_val
 
-    def get_pool_info(self, *, broker: ID, id_token: str, level: int) -> List[PoolInfoAvro]:
+    def get_broker_query_model(self, *, broker: ID, id_token: str, level: int) -> BrokerQueryModelAvro:
         raise ManageException(Constants.NOT_IMPLEMENTED)
 
     def claim_delegations(self, *, broker: ID, did: ID, id_token: str = None) -> DelegationAvro:
@@ -181,20 +180,7 @@ class KafkaController(KafkaActor, ABCMgmtControllerMixin):
     def demand_reservation_rid(self, *, rid: ID) -> bool:
         raise ManageException(Constants.NOT_IMPLEMENTED)
 
-    def extend_reservation(self, *, reservation: ID, new_end_time: datetime, new_units: int,
-                           new_resource_type: ResourceType = None, request_properties: dict = None,
-                           config_properties: dict = None) -> bool:
-        raise ManageException(Constants.NOT_IMPLEMENTED)
-
-    def extend_reservation_end_time(self, *, reservation: ID, new_end_time: datetime) -> bool:
-        raise ManageException(Constants.NOT_IMPLEMENTED)
-
-    def extend_reservation_end_time_request(self, *, reservation: ID, new_end_time: datetime,
-                                            request_properties: dict) -> bool:
-        raise ManageException(Constants.NOT_IMPLEMENTED)
-
-    def extend_reservation_end_time_request_config(self, *, reservation: ID, new_end_time: datetime,
-                                                   request_properties: dict, config_properties: dict) -> bool:
+    def extend_reservation(self, *, reservation: ID, new_end_time: datetime) -> bool:
         raise ManageException(Constants.NOT_IMPLEMENTED)
 
     def modify_reservation(self, *, rid: ID, modify_properties: dict) -> bool:
