@@ -299,7 +299,8 @@ class KafkaActorService(KafkaService):
 
             auth = Translate.translate_auth_from_avro(auth_avro=request.auth)
             mo = self.get_actor_mo(guid=ID(uid=request.guid))
-            result.status = mo.remove_reservation(caller=auth, rid=ID(uid=request.reservation_id))
+            result.status = mo.remove_reservation(caller=auth, rid=ID(uid=request.reservation_id),
+                                                  id_token=request.id_token)
 
         except Exception as e:
             result.status.set_code(ErrorCodes.ErrorInternalError.value)
@@ -324,9 +325,11 @@ class KafkaActorService(KafkaService):
             mo = self.get_actor_mo(guid=ID(uid=request.guid))
 
             if request.get_slice_id() is not None:
-                result.status = mo.close_slice_reservations(caller=auth, slice_id=ID(uid=request.slice_id))
+                result.status = mo.close_slice_reservations(caller=auth, slice_id=ID(uid=request.slice_id),
+                                                            id_token=request.id_token)
             else:
-                result.status = mo.close_reservation(caller=auth, rid=ID(uid=request.reservation_id))
+                result.status = mo.close_reservation(caller=auth, rid=ID(uid=request.reservation_id),
+                                                     id_token=request.id_token)
 
         except Exception as e:
             result.status.set_code(ErrorCodes.ErrorInternalError.value)
@@ -377,14 +380,15 @@ class KafkaActorService(KafkaService):
 
             if request.get_delegation_id() is not None:
                 result = mo.get_delegations(caller=auth, did=ID(uid=request.get_delegation_id()),
-                                            id_token=request.get_id_token())
+                                            id_token=request.get_id_token(), state=request.delegation_state)
 
             elif request.get_slice_id() is not None:
                 result = mo.get_delegations(caller=auth, slice_id=ID(uid=request.get_slice_id()),
-                                            id_token=request.get_id_token())
+                                            id_token=request.get_id_token(), state=request.delegation_state)
 
             else:
-                result = mo.get_delegations(caller=auth, id_token=request.get_id_token())
+                result = mo.get_delegations(caller=auth, id_token=request.get_id_token(),
+                                            state=request.delegation_state)
 
         except Exception as e:
             result.status.set_code(ErrorCodes.ErrorInternalError.value)
