@@ -24,6 +24,8 @@
 #
 # Author: Komal Thareja (kthare10@renci.org)
 from __future__ import annotations
+
+import traceback
 from typing import TYPE_CHECKING, List
 
 from fabric_mb.message_bus.messages.delegation_avro import DelegationAvro
@@ -59,7 +61,7 @@ class LocalActor(LocalProxy, ABCMgmtActor):
             if result.status.get_code() == 0:
                 return result.slices
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return None
 
@@ -71,49 +73,49 @@ class LocalActor(LocalProxy, ABCMgmtActor):
 
             return result.get_code() == 0
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return False
 
     def get_reservations(self, *, id_token: str = None, state: int = None,
-                         slice_id: ID = None, rid: ID = None) -> List[ReservationMng]:
+                         slice_id: ID = None, rid: ID = None, oidc_claim_sub: str = None) -> List[ReservationMng]:
         self.clear_last()
         try:
             result = self.manager.get_reservations(caller=self.auth, state=state, slice_id=slice_id, rid=rid,
-                                                   id_token=id_token)
+                                                   id_token=id_token, oidc_claim_sub=oidc_claim_sub)
             self.last_status = result.status
 
             if result.status.get_code() == 0:
                 return result.reservations
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return None
 
-    def remove_reservation(self, *, rid: ID) -> bool:
+    def remove_reservation(self, *, rid: ID, id_token: str = None) -> bool:
         self.clear_last()
         try:
-            result = self.manager.remove_reservation(caller=self.auth, rid=rid)
+            result = self.manager.remove_reservation(caller=self.auth, rid=rid, id_token=id_token)
             self.last_status = result
 
             return result.get_code() == 0
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return False
 
-    def close_reservation(self, *, rid: ID) -> bool:
+    def close_reservation(self, *, rid: ID, id_token: str = None) -> bool:
         self.clear_last()
         try:
-            result = self.manager.close_reservation(caller=self.auth, rid=rid)
+            result = self.manager.close_reservation(caller=self.auth, rid=rid, id_token=id_token)
             self.last_status = result
 
             return result.get_code() == 0
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return False
 
@@ -133,7 +135,7 @@ class LocalActor(LocalProxy, ABCMgmtActor):
                 return ID(uid=result.get_result())
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return None
 
@@ -147,7 +149,7 @@ class LocalActor(LocalProxy, ABCMgmtActor):
                 return True
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return False
 
@@ -164,21 +166,21 @@ class LocalActor(LocalProxy, ABCMgmtActor):
                 return True
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return False
 
-    def close_reservations(self, *, slice_id: ID) -> bool:
+    def close_reservations(self, *, slice_id: ID, id_token: str = None) -> bool:
         self.clear_last()
         try:
-            result = self.manager.close_slice_reservations(caller=self.auth, slice_id=slice_id)
+            result = self.manager.close_slice_reservations(caller=self.auth, slice_id=slice_id, id_token=id_token)
             self.last_status = result
 
             if self.last_status.get_code() == 0:
                 return True
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return False
 
@@ -193,7 +195,7 @@ class LocalActor(LocalProxy, ABCMgmtActor):
                 return result.reservation_states
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return None
 
@@ -209,6 +211,6 @@ class LocalActor(LocalProxy, ABCMgmtActor):
                 return result.reservations
 
         except Exception as e:
-            self.last_exception = e
+            self.on_exception(e=e, traceback_str=traceback.format_exc())
 
         return None
