@@ -32,7 +32,7 @@ from datetime import datetime
 from enum import Enum
 from typing import TYPE_CHECKING, Tuple, List
 
-from fim.graph.abc_property_graph import ABCPropertyGraphConstants
+from fim.graph.abc_property_graph import ABCPropertyGraphConstants, GraphFormat
 from fim.graph.resources.abc_adm import ABCADMPropertyGraph
 from fim.pluggable import PluggableRegistry, PluggableType
 from fim.slivers.base_sliver import BaseSliver
@@ -54,7 +54,7 @@ from fabric_cf.actor.core.util.reservation_set import ReservationSet
 from fabric_cf.actor.core.policy.inventory import Inventory
 from fabric_cf.actor.core.apis.abc_client_reservation import ABCClientReservation
 from fabric_cf.actor.fim.fim_helper import FimHelper
-from fabric_cf.actor.fim.plugins.broker.aggregate_bqm_plugin import AggregateBQMPlugin
+from fabric_cf.actor.fim.plugins.broker.aggregate_bqm_plugin import AggregatedBQMPlugin
 
 if TYPE_CHECKING:
     from fabric_cf.actor.core.apis.abc_broker_mixin import ABCBrokerMixin
@@ -161,8 +161,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
         self.combined_broker_model = FimHelper.get_neo4j_cbm_graph(graph_id=self.combined_broker_model_graph_id)
         self.combined_broker_model_graph_id = self.combined_broker_model.get_graph_id()
         self.logger.debug(f"Successfully loaded an Combined Broker Model Graph: {self.combined_broker_model_graph_id}")
-        # TODO uncomment post complete integration
-        self.pluggable_registry.register_pluggable(t=PluggableType.Broker, p=AggregateBQMPlugin, actor=self.actor,
+        self.pluggable_registry.register_pluggable(t=PluggableType.Broker, p=AggregatedBQMPlugin, actor=self.actor,
                                                    logger=self.logger)
         self.logger.debug(f"Registered AggregateBQMPlugin")
 
@@ -443,7 +442,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
             comps=sliver.attached_components_info)
 
     def __candidate_links(self, sliver: NetworkLinkSliver) -> List[str]:
-        pass
+        return list()
 
     def ticket_inventory(self, *, reservation: ABCBrokerReservation, inv: InventoryForType, term: Term,
                          node_id_to_reservations: dict) -> Tuple[bool, dict]:
@@ -471,11 +470,11 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
 
             # no candidate nodes found
             if len(node_id_list) == 0:
+                self.logger.error(f'No candidates nodes found to serve {reservation}')
                 return False, node_id_to_reservations
 
             delegation_id = None
             sliver = None
-            # FIXME: walk the list to find First/Best/Worst fit
             if self.get_algorithm_type().lower() == BrokerAllocationAlgorithm.FirstFit.name.lower():
                 delegation_id, sliver = self.__find_first_fit(node_id_list=node_id_list,
                                                               node_id_to_reservations=node_id_to_reservations,
@@ -645,16 +644,30 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
             raise BrokerException(error_code=ExceptionErrorCode.INVALID_ARGUMENT,
                                   msg=f"query_action {query_action}")
 
-        if query_action != Constants.QUERY_ACTION_DISCOVER_POOLS:
+        if query_action != Constants.QUERY_ACTION_DISCOVER_BQM:
             raise BrokerException(error_code=ExceptionErrorCode.INVALID_ARGUMENT,
                                   msg=f"query_action {query_action}")
 
+        bqm_format = p.get(Constants.BROKER_QUERY_MODEL_FORMAT, None)
+        if bqm_format is not None:
+            bqm_format = GraphFormat(int(bqm_format))
+        else:
+            bqm_format = GraphFormat.GRAPHML
+
         try:
             self.lock.acquire()
             if self.combined_broker_model is not None:
                 graph = self.combined_broker_model.get_bqm(query_level=query_level)
-                result[Constants.BROKER_QUERY_MODEL] = graph.serialize_graph()
-                result[Constants.QUERY_RESPONSE_STATUS] = "True"
+                graph_string = None
+                if graph is not None:
+                    graph_string = graph.serialize_graph(format=bqm_format)
+                if graph_string is not None:
+                    result[Constants.BROKER_QUERY_MODEL] = graph_string
+                    result[Constants.QUERY_RESPONSE_STATUS] = "True"
+                else:
+                    result[Constants.BROKER_QUERY_MODEL] = ""
+                    result[Constants.QUERY_RESPONSE_STATUS] = "False"
+                    result[Constants.QUERY_RESPONSE_MESSAGE] = "Resource(s) not found"
                 graph.delete_graph()
         except Exception as e:
             self.logger.error(traceback.format_exc())
@@ -779,6 +792,8 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
                 snapshot_graph_id = self.combined_broker_model.snapshot()
             self.combined_broker_model.merge_adm(adm=adm_graph)
             self.combined_broker_model.validate_graph()
+            # delete the snapshot
+            self.combined_broker_model.importer.delete_graph(graph_id=snapshot_graph_id)
         except Exception as e:
             self.logger.error(f"Exception occurred: {e}")
             self.logger.error(traceback.format_exc())
