@@ -164,7 +164,7 @@ class NetworkNodeControl(ResourceControl):
         :raises: AuthorityException in case the request cannot be satisfied
         """
 
-        if graph_node.capacity_delegations is None or len(graph_node.capacity_delegations) < 1 or reservation is None:
+        if graph_node.capacity_delegations is None or reservation is None:
             raise AuthorityException(Constants.INVALID_ARGUMENT)
 
         delegated_capacities = graph_node.get_capacity_delegations()
@@ -200,10 +200,11 @@ class NetworkNodeControl(ResourceControl):
 
             # Check components
             # Check if Components can be allocated
-            self.__check_components(rid=reservation.get_reservation_id(),
-                                    requested_components=requested.attached_components_info,
-                                    graph_node=graph_node,
-                                    existing_reservations=existing_reservations)
+            if requested.attached_components_info is not None:
+                self.__check_components(rid=reservation.get_reservation_id(),
+                                        requested_components=requested.attached_components_info,
+                                        graph_node=graph_node,
+                                        existing_reservations=existing_reservations)
 
             self.logger.debug(f"Slice properties: {reservation.get_slice().get_config_properties()}")
             unit = Unit(rid=reservation.get_reservation_id(), slice_id=reservation.get_slice_id(),
