@@ -386,7 +386,7 @@ class PsqlDatabase:
         return result
 
     def add_slice(self, *, act_id: int, slc_guid: str, slc_name: str, slc_type: int,
-                  slc_resource_type: str, properties, slc_graph_id: str = None):
+                  slc_resource_type: str, properties, slc_graph_id: str = None, oidc_claim_sub: str = None):
         """
         Add a slice
         @param act_id actor id
@@ -396,9 +396,10 @@ class PsqlDatabase:
         @param slc_resource_type slice resource type
         @param properties pickled instance
         @param slc_graph_id slice graph id
+        @param oidc_claim_sub User OIDC Sub
         """
         try:
-            slc_obj = Slices(slc_guid=slc_guid, slc_name=slc_name, slc_type=slc_type,
+            slc_obj = Slices(slc_guid=slc_guid, slc_name=slc_name, slc_type=slc_type, oidc_claim_sub=oidc_claim_sub,
                              slc_resource_type=slc_resource_type, properties=properties, slc_act_id=act_id)
             if slc_graph_id is not None:
                 slc_obj.slc_graph_id = slc_graph_id
@@ -520,18 +521,43 @@ class PsqlDatabase:
             raise e
         return result
 
-    def get_slice_by_name(self, *, act_id: int, slice_name: str) -> list:
+    def get_slice_by_name(self, *, act_id: int, slice_name: str, oidc_claim_sub: str = None) -> list:
         """
         Get slice for an actor
         @param act_id actor id
         @param slice_name slice name
+        @param oidc_claim_sub User OIDC Sub claim
         @return slice dictionary
         """
         result = []
         try:
             with session_scope(self.db_engine) as session:
-                for row in session.query(Slices).filter(Slices.slc_act_id == act_id).filter(
-                        Slices.slc_name == slice_name):
+                rows = []
+                if oidc_claim_sub is not None:
+                    rows = session.query(Slices).filter(Slices.slc_act_id == act_id).filter(
+                        Slices.slc_name == slice_name).filter(Slices.oidc_claim_sub == oidc_claim_sub)
+                else:
+                    rows = session.query(Slices).filter(Slices.slc_act_id == act_id).filter(
+                        Slices.slc_name == slice_name)
+                for row in rows:
+                    slice_obj = self.generate_slice_dict_from_row(row)
+                    result.append(slice_obj.copy())
+                    slice_obj.clear()
+        except Exception as e:
+            self.logger.error(Constants.EXCEPTION_OCCURRED.format(e))
+            raise e
+        return result
+
+    def get_slice_by_oidc_claim_sub(self, *, oidc_claim_sub: str) -> list:
+        """
+        Get slice for an user
+        @param oidc_claim_sub User OIDC SUB name
+        @return slice dictionary
+        """
+        result = []
+        try:
+            with session_scope(self.db_engine) as session:
+                for row in session.query(Slices).filter(Slices.oidc_claim_sub == oidc_claim_sub):
                     slice_obj = self.generate_slice_dict_from_row(row)
                     result.append(slice_obj.copy())
                     slice_obj.clear()
@@ -622,7 +648,8 @@ class PsqlDatabase:
         return result
 
     def add_reservation(self, *, act_id: int, slc_guid: str, rsv_resid: str, rsv_category: int, rsv_state: int,
-                        rsv_pending: int, rsv_joining: int, properties, rsv_graph_node_id: str = None):
+                        rsv_pending: int, rsv_joining: int, properties, rsv_graph_node_id: str = None,
+                        oidc_claim_sub: str = None):
         """
         Add a reservation
         @param act_id actor id
@@ -634,12 +661,13 @@ class PsqlDatabase:
         @param rsv_joining join state
         @param properties pickled instance
         @param rsv_graph_node_id graph id
+        @param oidc_claim_sub OIDC Sub claim
         """
         try:
             slc_obj = self.get_slice(act_id=act_id, slice_guid=slc_guid)
             rsv_obj = Reservations(rsv_slc_id=slc_obj['slc_id'], rsv_resid=rsv_resid, rsv_category=rsv_category,
                                    rsv_state=rsv_state, rsv_pending=rsv_pending, rsv_joining=rsv_joining,
-                                   properties=properties)
+                                   properties=properties, oidc_claim_sub=oidc_claim_sub)
             if rsv_graph_node_id is not None:
                 rsv_obj.rsv_graph_node_id = rsv_graph_node_id
             with session_scope(self.db_engine) as session:
@@ -730,6 +758,24 @@ class PsqlDatabase:
             raise e
         return result
 
+    def get_reservations_by_oidc_claim_sub(self, *, oidc_claim_sub: str) -> list:
+        """
+        Get Reservations for an actor
+        @param oidc_claim_sub OIDC Claim Sub
+        @return list of reservations
+        """
+        result = []
+        try:
+            with session_scope(self.db_engine) as session:
+                for row in session.query(Reservations).filter(Reservations.oidc_claim_sub == oidc_claim_sub):
+                    rsv_obj = self.generate_reservation_dict_from_row(row)
+                    result.append(rsv_obj.copy())
+                    rsv_obj.clear()
+        except Exception as e:
+            self.logger.error(Constants.EXCEPTION_OCCURRED.format(e))
+            raise e
+        return result
+
     def get_reservations_by_graph_node_id(self, *, graph_node_id: str) -> list:
         """
         Get Reservations by graph_node_id
@@ -917,11 +963,12 @@ class PsqlDatabase:
             raise e
         return result
 
-    def get_reservation(self, *, act_id: int, rsv_resid: str) -> dict:
+    def get_reservation(self, *, act_id: int, rsv_resid: str, oidc_claim_sub: str = None) -> dict:
         """
         Get Reservation for an actor
         @param act_id actor id
         @param rsv_resid reservation guid
+        @param oidc_claim_sub oidc claim sub
         @return list of reservations
         """
         result = None
@@ -930,8 +977,15 @@ class PsqlDatabase:
             if slc_id_list is None or len(slc_id_list) == 0:
                 raise DatabaseException(self.OBJECT_NOT_FOUND.format("Slice", act_id))
             with session_scope(self.db_engine) as session:
-                rsv_obj = session.query(Reservations).filter(
-                    Reservations.rsv_resid == rsv_resid).filter(Reservations.rsv_slc_id.in_(slc_id_list)).first()
+                rsv_obj = None
+                if oidc_claim_sub is None:
+                    rsv_obj = session.query(Reservations).filter(
+                        Reservations.rsv_resid == rsv_resid).filter(Reservations.rsv_slc_id.in_(slc_id_list)).first()
+                else:
+                    rsv_obj = session.query(Reservations).filter(
+                        Reservations.rsv_resid == rsv_resid).filter(
+                        Reservations.oidc_claim_sub == oidc_claim_sub).filter(
+                        Reservations.rsv_slc_id.in_(slc_id_list)).first()
                 if rsv_obj is None:
                     raise DatabaseException(self.OBJECT_NOT_FOUND.format("Reservation", rsv_resid))
                 result = self.generate_reservation_dict_from_row(rsv_obj)
@@ -1544,19 +1598,27 @@ class PsqlDatabase:
 
         return dlg_obj
 
-    def get_delegations(self, *, dlg_act_id: int) -> list:
+    def get_delegations(self, *, dlg_act_id: int, state: int = None) -> list:
         """
         Get delegations
         @param dlg_act_id actor id
+        @param state delegation state
         @param list of delegations
         """
         result = []
         try:
             with session_scope(self.db_engine) as session:
-                for row in session.query(Delegations).filter(Delegations.dlg_act_id == dlg_act_id):
-                    dlg_obj = self.generate_delegation_dict_from_row(row)
-                    result.append(dlg_obj.copy())
-                    dlg_obj.clear()
+                if state is None:
+                    for row in session.query(Delegations).filter(Delegations.dlg_act_id == dlg_act_id):
+                        dlg_obj = self.generate_delegation_dict_from_row(row)
+                        result.append(dlg_obj.copy())
+                        dlg_obj.clear()
+                else:
+                    for row in session.query(Delegations).filter(Delegations.dlg_act_id == dlg_act_id).filter(
+                            Delegations.dlg_state == state):
+                        dlg_obj = self.generate_delegation_dict_from_row(row)
+                        result.append(dlg_obj.copy())
+                        dlg_obj.clear()
         except Exception as e:
             self.logger.error(Constants.EXCEPTION_OCCURRED.format(e))
             raise e
@@ -1583,11 +1645,12 @@ class PsqlDatabase:
             raise e
         return result
 
-    def get_delegations_by_slice_id(self, *, dlg_act_id: int, slc_guid: str) -> list:
+    def get_delegations_by_slice_id(self, *, dlg_act_id: int, slc_guid: str, state: int = None) -> list:
         """
         Get delegations
         @param dlg_act_id actor id
         @param slc_guid slice id
+        @param state delegation state
         @return list of delegations
         """
         result = []
@@ -1596,10 +1659,17 @@ class PsqlDatabase:
             if slc_obj is None:
                 raise DatabaseException(self.OBJECT_NOT_FOUND.format("Slice", slc_guid))
             with session_scope(self.db_engine) as session:
-                for row in session.query(Delegations).filter(Delegations.dlg_slc_id == slc_obj['slc_id']):
-                    rsv_obj = self.generate_delegation_dict_from_row(row)
-                    result.append(rsv_obj.copy())
-                    rsv_obj.clear()
+                if state is None:
+                    for row in session.query(Delegations).filter(Delegations.dlg_slc_id == slc_obj['slc_id']):
+                        rsv_obj = self.generate_delegation_dict_from_row(row)
+                        result.append(rsv_obj.copy())
+                        rsv_obj.clear()
+                else:
+                    for row in session.query(Delegations).filter(Delegations.dlg_slc_id == slc_obj['slc_id']).filter(
+                            Delegations.dlg_state == state):
+                        rsv_obj = self.generate_delegation_dict_from_row(row)
+                        result.append(rsv_obj.copy())
+                        rsv_obj.clear()
         except Exception as e:
             self.logger.error(Constants.EXCEPTION_OCCURRED.format(e))
             raise e
@@ -1691,10 +1761,10 @@ def test():
     print("Proxies after remove {}".format(db.get_proxies(act_id=actor_id)))
 
     # Config Mapping operations
-    db.add_config_mapping(act_id=actor_id, cfgm_type="cfg-1", cfgm_path="/abc/def", properties=prop)
+    db.add_config_mapping(act_id=actor_id, cfgm_type="cfg-1", properties=prop)
     print("Config Mappings after add {}".format(db.get_config_mappings(act_id=actor_id)))
     prop['cfg-update'] = 'done'
-    db.update_config_mapping(act_id=actor_id, cfgm_type="cfg-1", cfgm_path="/abc/def", properties=prop)
+    db.update_config_mapping(act_id=actor_id, cfgm_type="cfg-1", properties=prop)
     print("Config Mappings after update by type {}".format(db.get_config_mappings_by_type(act_id=actor_id,
                                                                                           cfgm_type="cfg-1")))
     db.remove_config_mapping(cfgm_type="cfg-1")
