@@ -29,3 +29,14 @@ class OrchestratorException(Exception):
     """
     Orchestrator Exception
     """
+    HTTP_OK = 200
+    HTTP_5XX_ERROR = 500
+    HTTP_NOT_FOUND = 404
+    HTTP_BAD_REQUEST = 400
+
+    def __init__(self, message: str, http_error_code: int = HTTP_5XX_ERROR):
+        super().__init__(message)
+        self.http_error_code = http_error_code
+
+    def get_http_error_code(self) -> int:
+        return self.http_error_code
