@@ -34,7 +34,7 @@ from fabric_cf.actor.core.kernel.reservation_states import ReservationStates
 from fabric_cf.actor.core.time.actor_clock import ActorClock
 from fabric_cf.actor.fim.fim_helper import FimHelper
 from fabric_cf.actor.core.apis.abc_mgmt_controller_mixin import ABCMgmtControllerMixin
-from fabric_cf.actor.core.common.constants import Constants
+from fabric_cf.actor.core.common.constants import Constants, ErrorCodes
 from fabric_cf.actor.core.kernel.slice_state_machine import SliceState
 from fabric_cf.actor.core.util.id import ID
 from fabric_cf.actor.security.fabric_token import FabricToken
@@ -96,8 +96,9 @@ class OrchestratorHandler:
 
         return None
 
-    def discover_types(self, *, controller: ABCMgmtControllerMixin, token: str, level: int = 10,
-                       delete_graph: bool = True, ignore_validation: bool = True) -> Tuple[dict, Neo4jCBMGraph]:
+    def discover_broker_query_model(self, *, controller: ABCMgmtControllerMixin, token: str,
+                                    level: int = 10, delete_graph: bool = True,
+                                    ignore_validation: bool = True) -> Tuple[str, Neo4jCBMGraph]:
         """
         Discover all the available resources by querying Broker
         :param controller Management Controller Object
@@ -112,30 +113,24 @@ class OrchestratorHandler:
             raise OrchestratorException("Unable to determine broker proxy for this controller. "
                                         "Please check Orchestrator container configuration and logs.")
 
-        my_pools = controller.get_pool_info(broker=broker, id_token=token, level=level)
-        if my_pools is None or len(my_pools) != 1:
+        model = controller.get_broker_query_model(broker=broker, id_token=token, level=level)
+        if model is None:
             raise OrchestratorException(f"Could not discover types: {controller.get_last_error()}")
 
-        response = None
-        graph = None
-        for p in my_pools:
-            try:
-                status = p.properties.get(Constants.QUERY_RESPONSE_STATUS, "False")
-                if status.lower() != "false":
-                    bqm = p.properties.get(Constants.BROKER_QUERY_MODEL, None)
-                    if bqm is not None:
-                        graph = FimHelper.get_neo4j_cbm_graph_from_string_direct(graph_str=bqm,
-                                                                                 ignore_validation=ignore_validation)
-                        if delete_graph:
-                            FimHelper.delete_graph(graph_id=graph.get_graph_id())
-                    response = bqm
-                else:
-                    self.logger.error(p.properties.get(Constants.QUERY_RESPONSE_MESSAGE))
-            except Exception as e:
-                self.logger.error(traceback.format_exc())
-                self.logger.debug(f"Could not process discover types response {e}")
-
-        return response, graph
+        graph_ml = model.get_model()
+        try:
+            if graph_ml is not None and graph_ml != '':
+                graph = FimHelper.get_neo4j_cbm_graph_from_string_direct(graph_str=graph_ml,
+                                                                         ignore_validation=ignore_validation)
+                if delete_graph:
+                    FimHelper.delete_graph(graph_id=graph.get_graph_id())
+                return graph_ml, graph
+            else:
+                raise OrchestratorException(http_error_code=OrchestratorException.HTTP_NOT_FOUND,
+                                            message="Resource(s) not found!")
+        except Exception as e:
+            self.logger.error(traceback.format_exc())
+            raise e
 
     def list_resources(self, *, token: str, level: int) -> dict:
         """
@@ -149,15 +144,8 @@ class OrchestratorHandler:
             controller = self.controller_state.get_management_actor()
             self.logger.debug(f"list_resources invoked controller:{controller}")
 
-            try:
-                broker_query_model, graph = self.discover_types(controller=controller, token=token, level=level,
-                                                                ignore_validation=True)
-            except Exception as e:
-                self.logger.error(f"Failed to populate broker models e: {e}")
-                raise e
-
-            if broker_query_model is None:
-                raise OrchestratorException("Failed to populate abstract models")
+            broker_query_model, graph = self.discover_broker_query_model(controller=controller, token=token,
+                                                                         level=level, ignore_validation=True)
 
             return ResponseBuilder.get_broker_query_model_summary(bqm=broker_query_model)
 
@@ -166,13 +154,15 @@ class OrchestratorHandler:
             self.logger.error(f"Exception occurred processing list_resources e: {e}")
             raise e
 
-    def create_slice(self, *, token: str, slice_name: str, slice_graph: str, ssh_key: str) -> dict:
+    def create_slice(self, *, token: str, slice_name: str, slice_graph: str, ssh_key: str,
+                     lease_end_time: str) -> dict:
         """
         Create a slice
         :param token Fabric Identity Token
         :param slice_name Slice Name
         :param slice_graph Slice Graph Model
         :param ssh_key: User ssh key
+        :param lease_end_time: Lease End Time (UTC)
         :raises Raises an exception in case of failure
         :returns List of reservations created for the Slice on success
         """
@@ -182,6 +172,10 @@ class OrchestratorHandler:
         bqm_graph = None
         asm_graph = None
         try:
+            end_time = None
+            if lease_end_time is not None:
+                end_time = self.__validate_lease_end_time(lease_end_time=lease_end_time)
+
             controller = self.controller_state.get_management_actor()
             self.logger.debug(f"create_slice invoked for Controller: {controller}")
 
@@ -195,15 +189,8 @@ class OrchestratorHandler:
 
             asm_graph = FimHelper.get_neo4j_asm_graph(slice_graph=slice_graph)
 
-            try:
-                bqm_string, bqm_graph = self.discover_types(controller=controller, token=token, delete_graph=False)
-            except Exception as e:
-                self.logger.error(f"Exception occurred while listing resources e: {e}")
-                raise e
-
-            if bqm_graph is None:
-                self.logger.error("Could not get Broker Query Model")
-                raise OrchestratorException("Broker Query Model not found!")
+            bqm_string, bqm_graph = self.discover_broker_query_model(controller=controller, token=token,
+                                                                     delete_graph=False)
 
             broker = self.get_broker(controller=controller)
             if broker is None:
@@ -233,7 +220,8 @@ class OrchestratorHandler:
 
             # Create Slivers from Slice Graph; Compute Reservations from Slivers;
             # Add Reservations to relational database;
-            computed_reservations = orchestrator_slice.create(bqm_graph=bqm_graph, slice_graph=asm_graph)
+            computed_reservations = orchestrator_slice.create(bqm_graph=bqm_graph, slice_graph=asm_graph,
+                                                              end_time=end_time)
 
             # Process the Slice i.e. Demand the computed reservations i.e. Add them to the policy
             # Once added to the policy; Actor Tick Handler will do following asynchronously:
@@ -265,7 +253,6 @@ class OrchestratorHandler:
         :raises Raises an exception in case of failure
         :returns List of reservations created for the Slice on success
         """
-        include_sliver = False
         try:
             controller = self.controller_state.get_management_actor()
             self.logger.debug(f"get_slivers invoked for Controller: {controller}")
@@ -276,13 +263,20 @@ class OrchestratorHandler:
             rid = None
             if sliver_id is not None:
                 rid = ID(uid=sliver_id)
-                include_sliver = True
 
             reservations = controller.get_reservations(id_token=token, slice_id=slice_guid, rid=rid)
             if reservations is None:
                 if controller.get_last_error() is not None:
                     self.logger.error(controller.get_last_error())
-                raise OrchestratorException(f"Slice# {slice_id} has no reservations")
+                    if controller.get_last_error().status.code == ErrorCodes.ErrorNoSuchSlice:
+                        raise OrchestratorException(f"Slice# {slice_id} not found",
+                                                    http_error_code=OrchestratorException.HTTP_NOT_FOUND)
+                    elif controller.get_last_error().status.code == ErrorCodes.ErrorNoSuchReservation:
+                        raise OrchestratorException(f"Reservation# {rid} not found",
+                                                    http_error_code=OrchestratorException.HTTP_NOT_FOUND)
+
+                raise OrchestratorException(f"Slice# {slice_id} has no reservations",
+                                            http_error_code=OrchestratorException.HTTP_NOT_FOUND)
 
             return ResponseBuilder.get_reservation_summary(res_list=reservations, include_notices=include_notices,
                                                            include_sliver=True)
@@ -311,7 +305,8 @@ class OrchestratorHandler:
             if slice_list is None or len(slice_list) == 0:
                 if controller.get_last_error() is not None:
                     self.logger.error(controller.get_last_error())
-                raise OrchestratorException(f"User# has no Slices")
+                raise OrchestratorException(f"User# has no Slices",
+                                            http_error_code=OrchestratorException.HTTP_NOT_FOUND)
 
             return ResponseBuilder.get_slice_summary(slice_list=slice_list, slice_id=slice_id)
         except Exception as e:
@@ -337,13 +332,15 @@ class OrchestratorHandler:
             slice_list = controller.get_slices(id_token=token, slice_id=slice_guid)
 
             if slice_list is None or len(slice_list) == 0:
-                raise OrchestratorException(f"Slice# {slice_id} not found")
+                raise OrchestratorException(f"Slice# {slice_id} not found",
+                                            http_error_code=OrchestratorException.HTTP_NOT_FOUND)
 
             slice_object = next(iter(slice_list))
 
             slice_state = SliceState(slice_object.get_state())
             if slice_state == SliceState.Dead or slice_state == SliceState.Closing:
-                raise OrchestratorException(f"Slice# {slice_id} already closed")
+                raise OrchestratorException(f"Slice# {slice_id} already closed",
+                                            http_error_code=OrchestratorException.HTTP_BAD_REQUEST)
 
             if slice_state != SliceState.StableOK and slice_state != SliceState.StableError:
                 self.logger.info(f"Unable to delete Slice# {slice_guid} that is not yet stable, try again later")
@@ -377,7 +374,8 @@ class OrchestratorHandler:
             if slice_list is None or len(slice_list) == 0:
                 if controller.get_last_error() is not None:
                     self.logger.error(controller.get_last_error())
-                raise OrchestratorException(f"User# has no Slices")
+                raise OrchestratorException(f"User# has no Slices",
+                                            http_error_code=OrchestratorException.HTTP_NOT_FOUND)
 
             slice_obj = next(iter(slice_list))
 
@@ -395,13 +393,13 @@ class OrchestratorHandler:
             self.logger.error(f"Exception occurred processing get_slice_graph e: {e}")
             raise e
 
-    def renew_slice(self, *, token: str, slice_id: str, new_end_time: datetime):
+    def renew_slice(self, *, token: str, slice_id: str, new_lease_end_time: str):
         """
         Renew a slice
         :param token Fabric Identity Token
         :param slice_id Slice Id
-        :param new_end_time: New Lease End Time in UTC in '%Y-%m-%d %H:%M:%S' format
-=       :raises Raises an exception in case of failure
+        :param new_lease_end_time: New Lease End Time in UTC in '%Y-%m-%d %H:%M:%S' format
+        :raises Raises an exception in case of failure
         :return:
         """
         failed_to_extend_rid_list = []
@@ -416,27 +414,22 @@ class OrchestratorHandler:
             slice_list = controller.get_slices(id_token=token, slice_id=slice_guid)
 
             if slice_list is None or len(slice_list) == 0:
-                raise OrchestratorException(f"Slice# {slice_id} not found")
+                raise OrchestratorException(f"Slice# {slice_id} not found",
+                                            http_error_code=OrchestratorException.HTTP_NOT_FOUND)
 
             slice_object = next(iter(slice_list))
 
             slice_state = SliceState(slice_object.get_state())
             if slice_state == SliceState.Dead or slice_state == SliceState.Closing:
-                raise OrchestratorException(f"Slice# {slice_id} already closed")
+                raise OrchestratorException(f"Slice# {slice_id} already closed",
+                                            http_error_code=OrchestratorException.HTTP_BAD_REQUEST)
 
             if slice_state != SliceState.StableOK and slice_state != SliceState.StableError:
                 self.logger.info(f"Unable to renew Slice# {slice_guid} that is not yet stable, try again later")
                 raise OrchestratorException(f"Unable to renew Slice# {slice_guid} that is not yet stable, "
                                             f"try again later")
 
-            now = datetime.utcnow()
-            if new_end_time <= now:
-                raise OrchestratorException(f"New term end time {new_end_time} is in the past! "
-                                            f"Can't renew slice {slice_id}!")
-            if (new_end_time - now) > Constants.DEFAULT_MAX_DURATION:
-                self.logger.info(f"New term end time {new_end_time} exceeds system default "
-                                 f"{Constants.DEFAULT_MAX_DURATION}, setting to system default: ")
-                new_end_time = now + Constants.DEFAULT_MAX_DURATION
+            new_end_time = self.__validate_lease_end_time(lease_end_time=new_lease_end_time)
 
             reservations = controller.get_reservations(id_token=token, slice_id=slice_id)
             if reservations is None or len(reservations) < 1:
@@ -458,8 +451,8 @@ class OrchestratorHandler:
                     raise OrchestratorException(f"Attempted new term end time is shorter than current slice end time")
 
                 self.logger.debug(f"Extending reservation with reservation# {r.get_reservation_id()}")
-                result = controller.extend_reservation_end_time(reservation=ID(uid=r.get_reservation_id()),
-                                                                new_end_time=new_end_time)
+                result = controller.extend_reservation(reservation=ID(uid=r.get_reservation_id()),
+                                                       new_end_time=new_end_time)
                 if not result:
                     failed_to_extend_rid_list.append(r.get_reservation_id())
 
@@ -468,3 +461,30 @@ class OrchestratorHandler:
             self.logger.error(traceback.format_exc())
             self.logger.error(f"Exception occurred processing renew e: {e}")
             raise e
+
+    def __validate_lease_end_time(self, lease_end_time: str) -> datetime:
+        """
+        Validate Lease End Time
+        :param lease_end_time: New End Time
+        :return End Time
+        :raises Exception if new end time is in past
+        """
+        new_end_time = None
+        try:
+            new_end_time = datetime.strptime(lease_end_time, Constants.RENEW_TIME_FORMAT)
+        except Exception as e:
+            raise OrchestratorException(f"Lease End Time is not in format {Constants.RENEW_TIME_FORMAT}",
+                                        http_error_code=OrchestratorException.HTTP_BAD_REQUEST)
+
+        now = datetime.utcnow()
+        if new_end_time <= now:
+            raise OrchestratorException(f"New term end time {new_end_time} is in the past! ",
+                                        http_error_code=OrchestratorException.HTTP_BAD_REQUEST)
+
+        if (new_end_time - now) > Constants.DEFAULT_MAX_DURATION:
+            self.logger.info(f"New term end time {new_end_time} exceeds system default "
+                             f"{Constants.DEFAULT_MAX_DURATION}, setting to system default: ")
+
+            new_end_time = now + Constants.DEFAULT_MAX_DURATION
+
+        return new_end_time
