@@ -4,16 +4,17 @@ import connexion
 import six
 
 from fabric_cf.actor.core.common.constants import Constants
+from fabric_cf.orchestrator.core.exceptions import OrchestratorException
 from fabric_cf.orchestrator.core.orchestrator_handler import OrchestratorHandler
 from fabric_cf.orchestrator.swagger_server import received_counter, success_counter, failure_counter
 from fabric_cf.orchestrator.swagger_server.models.success import Success  # noqa: E501
 from fabric_cf.orchestrator.swagger_server.response.constants import POST_METHOD, SLICES_CREATE_PATH, \
     SLICES_GET_SLICE_ID_PATH, GET_METHOD, SLICES_GET_PATH, DELETE_METHOD, SLICES_DELETE_PATH, SLICES_RENEW_PATH, \
-    INTERNAL_SERVER_ERROR, BAD_REQUEST
+    INTERNAL_SERVER_ERROR, BAD_REQUEST, SLICE_STATUS_SLICE_ID_PATH
 from fabric_cf.orchestrator.swagger_server.response.utils import get_token
 
 
-def slices_create_post(body, slice_name, ssh_key):  # noqa: E501
+def slices_create_post(body, slice_name, ssh_key, lease_end_time):  # noqa: E501
     """Create slice
 
     Request to create slice as described in the request. Request would be a graph ML describing the requested resources.
@@ -27,6 +28,10 @@ def slices_create_post(body, slice_name, ssh_key):  # noqa: E501
     :type body: dict | bytes
     :param slice_name: Slice Name
     :type slice_name: str
+    :param ssh_key: User SSH Key
+    :type ssh_key: str
+    :param lease_end_time: Lease End Time for the Slice
+    :type lease_end_time: str
 
     :rtype: Success
     """
@@ -34,14 +39,20 @@ def slices_create_post(body, slice_name, ssh_key):  # noqa: E501
     handler = OrchestratorHandler()
     logger = handler.get_logger()
     received_counter.labels(POST_METHOD, SLICES_CREATE_PATH).inc()
+
     try:
         token = get_token()
         slice_graph = body.decode("utf-8")
-        value = handler.create_slice(token=token, slice_name=slice_name, slice_graph=slice_graph, ssh_key=ssh_key)
+        value = handler.create_slice(token=token, slice_name=slice_name, slice_graph=slice_graph,
+                                     ssh_key=ssh_key, lease_end_time=lease_end_time)
         response = Success()
         response.value = value
         success_counter.labels(POST_METHOD, SLICES_CREATE_PATH).inc()
         return response
+    except OrchestratorException as e:
+        logger.exception(e)
+        failure_counter.labels(POST_METHOD, SLICES_CREATE_PATH).inc()
+        return str(e), e.get_http_error_code()
     except Exception as e:
         logger.exception(e)
         failure_counter.labels(POST_METHOD, SLICES_CREATE_PATH).inc()
@@ -68,6 +79,10 @@ def slices_delete_slice_iddelete(slice_id):  # noqa: E501
         response = Success()
         success_counter.labels(DELETE_METHOD, SLICES_DELETE_PATH).inc()
         return response
+    except OrchestratorException as e:
+        logger.exception(e)
+        failure_counter.labels(DELETE_METHOD, SLICES_DELETE_PATH).inc()
+        return str(e), e.get_http_error_code()
     except Exception as e:
         logger.exception(e)
         failure_counter.labels(DELETE_METHOD, SLICES_DELETE_PATH).inc()
@@ -92,6 +107,10 @@ def slices_get():  # noqa: E501
         response.value = value
         success_counter.labels(GET_METHOD, SLICES_GET_PATH).inc()
         return response
+    except OrchestratorException as e:
+        logger.exception(e)
+        failure_counter.labels(GET_METHOD, SLICES_GET_PATH).inc()
+        return str(e), e.get_http_error_code()
     except Exception as e:
         logger.exception(e)
         failure_counter.labels(GET_METHOD, SLICES_GET_PATH).inc()
@@ -115,8 +134,8 @@ def slices_modify_slice_idput(body, slice_id):  # noqa: E501
 
     :rtype: Success
     """
-    if connexion.request.is_json:
-        body = str.from_dict(connexion.request.get_json())  # noqa: E501
+    slice_graph = body.decode("utf-8")
+
     return 'do some magic!'
 
 
@@ -151,21 +170,18 @@ def slices_renew_slice_idpost(slice_id, new_lease_end_time):  # noqa: E501
     handler = OrchestratorHandler()
     logger = handler.get_logger()
     received_counter.labels(POST_METHOD, SLICES_RENEW_PATH).inc()
-    new_end_time = None
-    try:
-        new_end_time = datetime.strptime(new_lease_end_time, Constants.RENEW_TIME_FORMAT)
-    except Exception as e:
-        logger.exception(e)
-        failure_counter.labels(POST_METHOD, SLICES_RENEW_PATH).inc()
-        return str(e), BAD_REQUEST
 
     try:
         token = get_token()
-        value = handler.renew_slice(token=token, slice_id=slice_id, new_end_time=new_end_time)
+        value = handler.renew_slice(token=token, slice_id=slice_id, new_lease_end_time=new_lease_end_time)
         response = Success()
         response.value = value
         success_counter.labels(POST_METHOD, SLICES_RENEW_PATH).inc()
         return response
+    except OrchestratorException as e:
+        logger.exception(e)
+        failure_counter.labels(POST_METHOD, SLICES_RENEW_PATH).inc()
+        return str(e), e.get_http_error_code()
     except Exception as e:
         logger.exception(e)
         failure_counter.labels(POST_METHOD, SLICES_RENEW_PATH).inc()
@@ -192,6 +208,10 @@ def slices_slice_idget(slice_id):  # noqa: E501
         response.value = value
         success_counter.labels(GET_METHOD, SLICES_GET_SLICE_ID_PATH).inc()
         return response
+    except OrchestratorException as e:
+        logger.exception(e)
+        failure_counter.labels(GET_METHOD, SLICES_GET_SLICE_ID_PATH).inc()
+        return str(e), e.get_http_error_code()
     except Exception as e:
         logger.exception(e)
         failure_counter.labels(GET_METHOD, SLICES_GET_SLICE_ID_PATH).inc()
@@ -213,15 +233,19 @@ def slices_status_slice_idget(slice_id):  # noqa: E501
     """
     handler = OrchestratorHandler()
     logger = handler.get_logger()
-    received_counter.labels(GET_METHOD, SLICES_GET_SLICE_ID_PATH).inc()
+    received_counter.labels(GET_METHOD, SLICE_STATUS_SLICE_ID_PATH).inc()
     try:
         token = get_token()
         value = handler.get_slices(token=token, slice_id=slice_id)
         response = Success()
         response.value = value
-        success_counter.labels(GET_METHOD, SLICES_GET_SLICE_ID_PATH).inc()
+        success_counter.labels(GET_METHOD, SLICE_STATUS_SLICE_ID_PATH).inc()
         return response
+    except OrchestratorException as e:
+        logger.exception(e)
+        failure_counter.labels(GET_METHOD, SLICE_STATUS_SLICE_ID_PATH).inc()
+        return str(e), e.get_http_error_code()
     except Exception as e:
         logger.exception(e)
-        failure_counter.labels(GET_METHOD, SLICES_GET_SLICE_ID_PATH).inc()
+        failure_counter.labels(GET_METHOD, SLICE_STATUS_SLICE_ID_PATH).inc()
         return str(e), INTERNAL_SERVER_ERROR
