@@ -19,7 +19,8 @@ class TestSlicesController(BaseTestCase):
         """
         body = 'body_example'
         query_string = [('slice_name', 'slice_name_example'),
-                        ('ssh_key', 'ssh_key_example')]
+                        ('ssh_key', 'ssh_key_example'),
+                        ('lease_end_time', 'lease_end_time_example')]
         response = self.client.open(
             '//slices/create',
             method='POST',
@@ -35,7 +36,7 @@ class TestSlicesController(BaseTestCase):
         Delete slice.
         """
         response = self.client.open(
-            '//slices/delete/{sliceID}'.format(slice_id='slice_id_example'),
+            '//slices/delete/{sliceID}'.format(sliceID='slice_id_example'),
             method='DELETE')
         self.assert200(response,
                        'Response body is : ' + response.data.decode('utf-8'))
@@ -58,7 +59,7 @@ class TestSlicesController(BaseTestCase):
         """
         body = 'body_example'
         response = self.client.open(
-            '//slices/modify/{sliceID}'.format(slice_id='slice_id_example'),
+            '//slices/modify/{sliceID}'.format(sliceID='slice_id_example'),
             method='PUT',
             data=json.dumps(body),
             content_type='text/plain')
@@ -71,7 +72,7 @@ class TestSlicesController(BaseTestCase):
         Redeem resources reserved via Create API
         """
         response = self.client.open(
-            '//slices/redeem/{sliceID}'.format(slice_id='slice_id_example'),
+            '//slices/redeem/{sliceID}'.format(sliceID='slice_id_example'),
             method='POST')
         self.assert200(response,
                        'Response body is : ' + response.data.decode('utf-8'))
@@ -83,7 +84,7 @@ class TestSlicesController(BaseTestCase):
         """
         query_string = [('new_lease_end_time', 'new_lease_end_time_example')]
         response = self.client.open(
-            '//slices/renew/{sliceID}'.format(slice_id='slice_id_example'),
+            '//slices/renew/{sliceID}'.format(sliceID='slice_id_example'),
             method='POST',
             query_string=query_string)
         self.assert200(response,
@@ -95,7 +96,7 @@ class TestSlicesController(BaseTestCase):
         slice properties
         """
         response = self.client.open(
-            '//slices/{sliceID}'.format(slice_id='slice_id_example'),
+            '//slices/{sliceID}'.format(sliceID='slice_id_example'),
             method='GET')
         self.assert200(response,
                        'Response body is : ' + response.data.decode('utf-8'))
@@ -106,7 +107,7 @@ class TestSlicesController(BaseTestCase):
         slice status
         """
         response = self.client.open(
-            '//slices/status/{sliceID}'.format(slice_id='slice_id_example'),
+            '//slices/status/{sliceID}'.format(sliceID='slice_id_example'),
             method='GET')
         self.assert200(response,
                        'Response body is : ' + response.data.decode('utf-8'))
